aboutsummaryrefslogtreecommitdiff
path: root/src/crypto/rand
diff options
context:
space:
mode:
Diffstat (limited to 'src/crypto/rand')
-rw-r--r--src/crypto/rand/rand.go2
-rw-r--r--src/crypto/rand/rand_getrandom.go4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/crypto/rand/rand.go b/src/crypto/rand/rand.go
index af85b966df..ac2635d1b3 100644
--- a/src/crypto/rand/rand.go
+++ b/src/crypto/rand/rand.go
@@ -11,7 +11,7 @@ import "io"
// Reader is a global, shared instance of a cryptographically
// secure random number generator.
//
-// On Linux, FreeBSD, Dragonfly and Solaris, Reader uses getrandom(2) if
+// On Linux, FreeBSD, Dragonfly, NetBSD and Solaris, Reader uses getrandom(2) if
// available, /dev/urandom otherwise.
// On OpenBSD and macOS, Reader uses getentropy(2).
// On other Unix-like systems, Reader reads from /dev/urandom.
diff --git a/src/crypto/rand/rand_getrandom.go b/src/crypto/rand/rand_getrandom.go
index 478aa5c459..46c4133a73 100644
--- a/src/crypto/rand/rand_getrandom.go
+++ b/src/crypto/rand/rand_getrandom.go
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
//go:build linux || freebsd || dragonfly || solaris
package rand
@@ -21,7 +21,7 @@ func init() {
// is returned by a single call to getrandom() on systems where int
// has a size of 32 bits.
maxGetRandomRead = (1 << 25) - 1
- case "freebsd", "dragonfly", "solaris", "illumos":
+ case "dragonfly", "freebsd", "illumos", "netbsd", "solaris":
maxGetRandomRead = 1 << 8
default:
panic("no maximum specified for GetRandom")
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
-//go:build linux || freebsd || dragonfly || solaris
+//go:build dragonfly || freebsd || linux || netbsd || solaris
package rand